'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.createRegExpConstraint = createRegExpConstraint;
exports.createMinConstraint = createMinConstraint;
exports.createMaxConstraint = createMaxConstraint;
exports.createMinLengthConstraint = createMinLengthConstraint;
exports.createMaxLengthConstraint = createMaxLengthConstraint;

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _utilCreateConstraint = require('./util/createConstraint');

var _utilCreateConstraint2 = _interopRequireDefault(_utilCreateConstraint);

var _validators = require('./validators');

var validators = _interopRequireWildcard(_validators);

// Type constraints

var isNotNull = (0, _utilCreateConstraint2['default'])(validators.isNotNull, 'Value is null or undefined');

exports.isNotNull = isNotNull;
var isNull = (0, _utilCreateConstraint2['default'])(validators.isNull, 'Value is neither null nor undefined');

exports.isNull = isNull;
var isBoolean = (0, _utilCreateConstraint2['default'])(validators.isBoolean, 'Value is not boolean');

exports.isBoolean = isBoolean;
var isTrue = (0, _utilCreateConstraint2['default'])(validators.isTrue, 'Value is not true');

exports.isTrue = isTrue;
var isFalse = (0, _utilCreateConstraint2['default'])(validators.isFalse, 'Value is not false');

exports.isFalse = isFalse;
var isNumber = (0, _utilCreateConstraint2['default'])(validators.isNumber, 'Value is not number');

exports.isNumber = isNumber;
var isNotANumber = (0, _utilCreateConstraint2['default'])(validators.isNotANumber, 'Value is not NaN');

exports.isNotANumber = isNotANumber;
var isInfinity = (0, _utilCreateConstraint2['default'])(validators.isInfinity, 'Value is not infinity');

exports.isInfinity = isInfinity;
var isString = (0, _utilCreateConstraint2['default'])(validators.isString, 'Value is not string');

exports.isString = isString;
var isObject = (0, _utilCreateConstraint2['default'])(validators.isObject, 'Value is not object');

exports.isObject = isObject;
var isPlainObject = (0, _utilCreateConstraint2['default'])(validators.isPlainObject, 'Value is not plain object');

exports.isPlainObject = isPlainObject;
var isArray = (0, _utilCreateConstraint2['default'])(validators.isArray, 'Value is not array');

exports.isArray = isArray;
var isRegExp = (0, _utilCreateConstraint2['default'])(validators.isRegExp, 'Value is not regular expression');

exports.isRegExp = isRegExp;
var isDate = (0, _utilCreateConstraint2['default'])(validators.isDate, 'Value is not date');

exports.isDate = isDate;
var isFunction = (0, _utilCreateConstraint2['default'])(validators.isFunction, 'Value is not function');

exports.isFunction = isFunction;
// String constraints

function createRegExpConstraint(regexp) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  return (0, _utilCreateConstraint2['default'])(function (value) {
    return validators.isString(value) && regexp.test(value);
  }, message || 'Value is not matched by pattern');
}

var isEmail = (0, _utilCreateConstraint2['default'])(validators.isEmail, 'Value is not valid email address');

exports.isEmail = isEmail;
var isUppercase = (0, _utilCreateConstraint2['default'])(validators.isUppercase, 'Value has symbols not in uppercase');

exports.isUppercase = isUppercase;
var isLowercase = (0, _utilCreateConstraint2['default'])(validators.isLowercase, 'Value has symbols not in lowercase');

exports.isLowercase = isLowercase;
// Number constraints

function createMinConstraint(min) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  return (0, _utilCreateConstraint2['default'])(function (value) {
    return value >= min;
  }, message || 'Value is less than ' + min);
}

function createMaxConstraint(max) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  return (0, _utilCreateConstraint2['default'])(function (value) {
    return value <= max;
  }, message || 'Value is more than ' + max);
}

// Length constraints

var isNotEmpty = (0, _utilCreateConstraint2['default'])(validators.isNotEmpty, 'Value is empty');

exports.isNotEmpty = isNotEmpty;
var isEmpty = (0, _utilCreateConstraint2['default'])(validators.isEmpty, 'Value is not empty');

exports.isEmpty = isEmpty;

function createMinLengthConstraint(minLength) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  return (0, _utilCreateConstraint2['default'])(function (value) {
    return value.length >= minLength;
  }, message || 'Value length is less than ' + minLength);
}

function createMaxLengthConstraint(maxLength) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  return (0, _utilCreateConstraint2['default'])(function (value) {
    return value.length <= maxLength;
  }, message || 'Value length is more than ' + maxLength);
}