'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = createObjectConstraint;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _executeMessage = require('./executeMessage');

var _executeMessage2 = _interopRequireDefault(_executeMessage);

function createObjectConstraint(constraints) {
  var message = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  var keys = Object.keys(constraints);

  return function (value, context) {
    if (!value || typeof value !== 'object') {
      return Promise.resolve({
        valid: false,
        message: (0, _executeMessage2['default'])(value, context, [], message || 'Object is not valid'),
        children: {}
      });
    }

    return Promise.all(keys.map(function (key) {
      return constraints[key](value[key], context);
    })).then(function (values) {
      var children = keys.reduce(function (acc, key, index) {
        return (acc[key] = values[index], acc);
      }, {});

      var valid = keys.every(function (key) {
        return children[key].valid;
      });

      return {
        valid: valid,
        message: valid ? null : (0, _executeMessage2['default'])(value, context, children, message || 'Object is not valid'),
        children: children
      };
    });
  };
}

module.exports = exports['default'];